@@ -35,7 +35,6 @@
 #include <libgnomeui/gnome-help.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
-#include <glade/glade.h>
 #include <glib/gi18n.h>
 #include <stdlib.h>
 #include <string.h>
@@ -472,6 +471,7 @@ cpufreq_applet_menu_popup (CPUFreqApplet *applet,
         if (!applet->popup) {
                 applet->popup = cpufreq_popup_new ();
                 cpufreq_popup_set_monitor (applet->popup, applet->monitor);
+		cpufreq_popup_set_parent (applet->popup, GTK_WIDGET (applet));
         }
 
         menu = cpufreq_popup_get_menu (applet->popup);
