@@ -7,6 +7,8 @@ import cPickle
 # Autotools set the actual data_dir in defs.py
 from defs import *
 
+DEBUGGING = False
+
 # Allow to use uninstalled invest ---------------------------------------------
 UNINSTALLED_INVEST = False
 def _check(path):
@@ -20,11 +22,14 @@ if _check(name):
 # Shared data dir is most the time /usr/share/invest-applet
 if UNINSTALLED_INVEST:
 	SHARED_DATA_DIR = abspath(join(dirname(__file__), '..', 'data'))
-	GLADE_DATA_DIR = SHARED_DATA_DIR
+	BUILDER_DATA_DIR = SHARED_DATA_DIR
+	ART_DATA_DIR = join(SHARED_DATA_DIR, 'art')
 else:
 	SHARED_DATA_DIR = join(DATA_DIR, "gnome-applets", "invest-applet")
-	GLADE_DATA_DIR = GLADEDIR
-print "Data Dir: %s" % SHARED_DATA_DIR
+	BUILDER_DATA_DIR = BUILDERDIR
+	ART_DATA_DIR = SHARED_DATA_DIR
+if DEBUGGING:
+	print "Data Dir: %s" % SHARED_DATA_DIR
 
 USER_INVEST_DIR = expanduser("~/.gnome2/invest-applet")
 if not exists(USER_INVEST_DIR):
@@ -38,9 +43,6 @@ if not exists(USER_INVEST_DIR):
 # when presenting save/open dialogs
 os.chdir(expanduser("~"))
 
-# Path to images, icons
-ART_DATA_DIR = SHARED_DATA_DIR
-
 #Gconf client
 GCONF_CLIENT = gconf.client_get_default()
 
@@ -60,11 +62,10 @@ GNOMEVFS_CHUNK_SIZE = 512*1024 # 512 KBytes
 AUTOREFRESH_TIMEOUT = 20*60*1000 # 15 minutes
 TICKER_TIMEOUT = 10000#3*60*1000#
 
-CHART_BASE_URL = "http://ichart.finance.yahoo.com/z?s=%(s)s&t=%(t)s&q=%(q)s&l=%(l)s&z=%(z)s&p=%(p)s&a=%(a)s%(opt)s"
 QUOTES_URL="http://finance.yahoo.com/d/quotes.csv?s=%(s)s&f=sl1d1t1c1ohgv&e=.csv"
 
-# Sample: "APPL",76.05,"1/9/2006","4:00pm",0.00,N/A,N/A,N/A,500
-QUOTES_CSV_FIELDS=["ticker", ("trade", float), "date", "time", ("variation", float)]
+# Sample (25/4/2008): UCG.MI,"4,86",09:37:00,2008/04/25,"0,07","4,82","4,87","4,82",11192336
+QUOTES_CSV_FIELDS=["ticker", ("trade", float), "time", "date", ("variation", float), ("open", float)]
 
 try:
 	STOCKS = cPickle.load(file(STOCKS_FILE))
